@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-07-08'; # DATE
-our $VERSION = '1.21'; # VERSION
+our $DATE = '2015-07-15'; # DATE
+our $VERSION = '1.22'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -472,6 +472,8 @@ sub action_subcommands {
 }
 
 sub action_version {
+    no strict 'refs';
+
     my ($self, $r) = @_;
 
     my @text;
@@ -482,6 +484,11 @@ sub action_version {
             " version ", ($meta->{entity_v} // "?"),
             ($meta->{entity_date} ? " ($meta->{entity_date})" : ''),
             "\n";
+        for my $mod (@{ $meta->{'x.dynamic_generator_modules'} // [] }) {
+            push @text, "  $mod version ", ${"$mod\::VERSION"},
+                (${"$mod\::DATE"} ? " (".${"$mod\::DATE"}.")" : ""),
+                    "\n";
+        }
     }
 
     for my $url (@{ $self->extra_urls_for_version // [] }) {
@@ -580,7 +587,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.21 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-07-08.
+This document describes version 1.22 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-07-15.
 
 =head1 SYNOPSIS
 
